@@ -7,7 +7,10 @@ else:
     import Growl as notify
 
 def display_notification(command, return_code):
-    description = u'finished with return code %s' % return_code
+    if return_code == 0:
+        description = u'finished successfully'
+    else:
+        description = u'finished with return code %s' % return_code
 
     if hasattr(notify, 'GrowlNotifier'):
         g = notify.GrowlNotifier(u'naf', notifications=['command_finished',])
